Learn R Programming

HARr (version 1.1.0)

read_har: Read a GEMPACK HAR file into R

Description

Reads in a GEMPACK HAR file and returns its representation a list. Currently can only process integer headers, real full headers and character headers

Usage

read_har(
  con,
  useCoefficientsAsNames = FALSE,
  toLowerCase = TRUE,
  headersToRead = NULL
)

Value

A list of headers

Arguments

con

Connection or path to HAR file

useCoefficientsAsNames

If a coefficient name is present in the header, use that instead of the four-letter header

toLowerCase

= TRUE Turn all strings to lower case

headersToRead

= NULL A vector of header names to read in

Examples

Run this code
fl <- system.file("extdata/example1.har", package="HARr")
read_har(fl)

Run the code above in your browser using DataLab