powered by
Reads in a GEMPACK HAR file and returns its representation a list. Currently can only process integer headers, real full headers and character headers
read_har( con, useCoefficientsAsNames = FALSE, toLowerCase = TRUE, headersToRead = NULL )
A list of headers
Connection or path to HAR file
If a coefficient name is present in the header, use that instead of the four-letter header
= TRUE Turn all strings to lower case
= NULL A vector of header names to read in
fl <- system.file("extdata/example1.har", package="HARr") read_har(fl)
Run the code above in your browser using DataLab